Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(376)

Unified Diff: chrome/browser/chromeos/gdata/gdata_util.h

Issue 10877005: Rename GDataCache* to DriveCache* (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_test_util.h ('k') | chrome/browser/chromeos/gdata/gdata_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/gdata/gdata_util.h
diff --git a/chrome/browser/chromeos/gdata/gdata_util.h b/chrome/browser/chromeos/gdata/gdata_util.h
index 7c7100d876e92e863ea284a37bbba95fa783d4c2..43cd146c35f73e38b55d0bdda30321a21a5f8ff0 100644
--- a/chrome/browser/chromeos/gdata/gdata_util.h
+++ b/chrome/browser/chromeos/gdata/gdata_util.h
@@ -57,9 +57,9 @@ const FilePath& GetSpecialRemoteRootPath();
GURL GetFileResourceUrl(const std::string& resource_id,
const std::string& file_name);
// Given a profile and a gdata_cache_path, return the file resource url.
void ModifyGDataFileResourceUrl(Profile* profile,
- const FilePath& gdata_cache_path,
+ const FilePath& drive_cache_path,
GURL* url);
// Returns true if the given path is under the GData mount point.
@@ -73,7 +73,7 @@ FilePath ExtractGDataPath(const FilePath& path);
// Inserts all possible cache paths for a given vector of paths on gdata mount
// point into the output vector |cache_paths|, and then invokes callback.
// Caller must ensure that |cache_paths| lives until the callback is invoked.
-void InsertGDataCachePathsPermissions(
+void InsertDriveCachePathsPermissions(
Profile* profile_,
scoped_ptr<std::vector<FilePath> > gdata_paths,
std::vector<std::pair<FilePath, int> >* cache_paths,
@@ -57,9 +57,9 @@ const FilePath& GetSpecialRemoteRootPath();
GURL GetFileResourceUrl(const std::string& resource_id,
const std::string& file_name);
-// Given a profile and a gdata_cache_path, return the file resource url.
+// Given a profile and a drive_cache_path, return the file resource url.
void ModifyGDataFileResourceUrl(Profile* profile,
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_test_util.h ('k') | chrome/browser/chromeos/gdata/gdata_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698